#!/bin/bash -l
# The above line must be first and must include the "-l"

# A job submission script for running a hybrid MPI/OpenMP job on stheno
# This will run on 2 nodes; 2 mpi tasks per node; 6 openmp threads per mpi task
#SBATCH --job-name=hellohybrid.intel
#SBATCH --output=hellohybrid.intel.%j.out # %j expands to slurm JobID
#SBATCH --nodes=2
#SBATCH --ntasks=4
#SBATCH --cpus-per-task=6

# Use "sinfo" to see what partitions are available to you
#SBATCH --partition=dms-short

# Memory required; lower amount gets scheduling priority
#SBATCH --mem-per-node=4G 

# Time required in d-hh:mm:ss format; lower time gets scheduling priority
#SBATCH --time=0-01:00:00

# Load the correct compiler and mpi
module purge > /dev/null 2>&1
module load intel impi

# Set OMP_NUM_THREADS to the same value as --cpus-per-task
# with a fallback in case it isn't set.
# SLURM_CPUS_PER_TASK is set to the value of --cpus-per-task, but only if --cpus-per-task is explicitly set
if [ -n "$SLURM_CPUS_PER_TASK" ]; then
  omp_threads=$SLURM_CPUS_PER_TASK
else
  omp_threads=1
fi
export OMP_NUM_THREADS=$omp_threads

# Run the process with mpirun. 
mpirun -launcher srun /full/path/to/hellohybrid
