#!/bin/bash -l
# The above line must be first and must include the "-l"

# Example with 12 cores
#SBATCH --job-name=omp_hello
#SBATCH --output=omp_hello.gnu.%j.out # %j expands to slurm JobID
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=1
#SBATCH --cpus-per-task=12

# Use "sinfo" to see what partitions are available to you
#SBATCH --partition=dms-short

# Memory required; lower amount gets scheduling priority
#SBATCH --mem-per-node=4G 

# Time required in d-hh:mm:ss format; lower time gets scheduling priority
#SBATCH --time=0-01:00:00

# Purge and load correct module
module purge  > /dev/null 2>&1
module load gnu8 

# Set OMP_NUM_THREADS to the same value as --cpus-per-task
# with a fallback in case it isn't set.
# SLURM_CPUS_PER_TASK is set to the value of --cpus-per-task, but only if --cpus-per-task is explicitly set
if [ -n "$SLURM_CPUS_PER_TASK" ]; then
  omp_threads=$SLURM_CPUS_PER_TASK
else
  omp_threads=1
fi
export OMP_NUM_THREADS=$omp_threads
/full/path/to/omp_hello
